--AH:ScriptId=1d5a88e6-1be2-4d6f-919e-5bf0862a6aa2;2995
CREATE TABLE [DatabaseConnections]
(
	[DatabaseConnection_Id] INT IDENTITY(1, 1) NOT NULL,
	[DatabaseConnection_Name] NVARCHAR(50) NULL,
	[DatabaseConnection_Description] NVARCHAR(MAX) NULL,
	[DatabaseConnection_Configuration] XML NOT NULL,
	[ExecuteOn_Server_Id] INT NULL,
	[ModifiedBy_User_Name] USERNAME NOT NULL,
	[ModifiedOn_Date] DATETIME NOT NULL,
	[Application_Id] INT NOT NULL,
	[Environment_Id] INT NOT NULL,

	CONSTRAINT [PK__DatabaseConnections]
		PRIMARY KEY ([DatabaseConnection_Id]),

	CONSTRAINT [FK__DatabaseConnections__Servers]
		FOREIGN KEY ([ExecuteOn_Server_Id])
		REFERENCES [Servers] ([Server_Id])
		ON DELETE SET NULL,

	CONSTRAINT [FK__DatabaseConnections__Applications]
		FOREIGN KEY ([Application_Id])
		REFERENCES [Applications] ([Application_Id])
		ON DELETE CASCADE,

	CONSTRAINT [FK__DatabaseConnections__Environments]
		FOREIGN KEY ([Environment_Id])
		REFERENCES [Environments] ([Environment_Id])
		ON DELETE CASCADE
)

GO

SET IDENTITY_INSERT [DatabaseConnections] ON
GO

INSERT INTO [DatabaseConnections]
(
	[DatabaseConnection_Id],
	[DatabaseConnection_Name],
	[DatabaseConnection_Description],
	[DatabaseConnection_Configuration],
	[ExecuteOn_Server_Id],
	[ModifiedBy_User_Name],
	[ModifiedOn_Date],
	[Application_Id],
	[Environment_Id]
)
SELECT P.[Provider_Id],
       P.[Provider_Name],
	   NULLIF(P.[Provider_Description], ''),
	   P.[Provider_Configuration],
	   CASE WHEN EXISTS(SELECT [Server_Id] FROM [Servers] WHERE [Server_Id] = P.[ExecuteOn_Server_Id]) THEN P.[ExecuteOn_Server_Id] ELSE NULL END,
	   COALESCE(P.[ModifiedBy_User_Name], P.[CreatedBy_User_Name], 'Unknown'),
	   COALESCE(P.[ModifiedOn_Date], P.[CreatedOn_Date], GETUTCDATE()),
	   DCSP.[Application_Id],
	   DCSP.[Environment_Id]
  FROM [DatabaseChangeScriptProviders] DCSP
       INNER JOIN [Providers] P
	           ON P.[Provider_Id] = DCSP.[Provider_Id]

GO

SET IDENTITY_INSERT [DatabaseConnections] OFF
GO

ALTER TABLE [DatabaseChangeScriptExecutions]
	DROP CONSTRAINT [FK__DatabaseChangeScriptExecutions__DatabaseChangeScriptProviders]
GO

EXEC sp_rename 'DatabaseChangeScriptExecutions.Provider_Id', 'DatabaseConnection_Id', 'COLUMN'
GO

EXEC sp_rename 'DatabaseChangeScriptExecutions', 'DatabaseChangeScriptLegacyExecutions'
GO

EXEC sp_rename 'PK__DatabaseChangeScriptExecutions', 'PK__DatabaseChangeScriptLegacyExecutions', 'OBJECT'
GO

EXEC sp_rename 'FK__DatabaseChangeScriptExecutions__Executions', 'FK__DatabaseChangeScriptLegacyExecutions__Executions', 'OBJECT'
GO

ALTER TABLE [DatabaseChangeScriptLegacyExecutions]
	ADD CONSTRAINT [FK__DatabaseChangeScriptLegacyExecutions__DatabaseConnections]
		FOREIGN KEY ([DatabaseConnection_Id])
		REFERENCES [DatabaseConnections] ([DatabaseConnection_Id])
		ON DELETE CASCADE

DROP TABLE [DatabaseChangeScriptProviders]

DELETE [Providers]
 WHERE [ProviderType_Code] = 'B'

GO

IF OBJECT_ID('[DatabaseChangeScripts_LogExecution]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_LogExecution]
IF OBJECT_ID('[DatabaseChangeScripts_GetDatabaseProviders]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_GetDatabaseProviders]
IF OBJECT_ID('[DatabaseChangeScripts_GetDatabaseProvider]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_GetDatabaseProvider]
IF OBJECT_ID('[DatabaseChangeScripts_DeleteDatabaseProvider]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_DeleteDatabaseProvider]
IF OBJECT_ID('[DatabaseChangeScripts_AddDatabaseProvider]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_AddDatabaseProvider]
IF OBJECT_ID('[DatabaseChangeScriptProviders_Extended]') IS NOT NULL DROP VIEW [DatabaseChangeScriptProviders_Extended]
IF OBJECT_ID('[DatabaseChangeScripts_GetDatabaseChangeScriptExecution]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_GetDatabaseChangeScriptExecution]
IF OBJECT_ID('[DatabaseChangeScripts_GetDatabaseChangeScriptExecutions]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_GetDatabaseChangeScriptExecutions]
