IF OBJECT_ID('TR__DeployableDependencies__CircularDependencyCheck') IS NOT NULL
DROP TRIGGER [TR__DeployableDependencies__CircularDependencyCheck]
GO

CREATE TRIGGER [TR__DeployableDependencies__CircularDependencyCheck]
ON [DeployableDependencies] AFTER UPDATE, INSERT AS
BEGIN

	SET NOCOUNT ON

	DECLARE @ResolvedDependencies TABLE(
		[Base_Deployable_Id] INT NOT NULL, 

		[Resolution_Depth] INT NOT NULL,
		[Dependant_Deployable_Id] INT NOT NULL, 
		[DependsOn_Deployable_Id] INT NOT NULL
	)

	DECLARE @depth INT, @row_count INT
	    SET @depth = 1
	    SET @row_count = 1 
	 
	INSERT INTO @ResolvedDependencies 
	  ([Base_Deployable_Id], [Resolution_Depth], [Dependant_Deployable_Id], [DependsOn_Deployable_Id])
	SELECT 
	   [Deployable_Id], 1, [Deployable_Id], [DependsOn_Deployable_Id]
	  FROM [inserted] 

	WHILE @row_count > 0
	BEGIN 
		SET @depth = @depth + 1

		-- insert all of the previous depth's dependecies from the actual table
		INSERT INTO @ResolvedDependencies 
		  ([Base_Deployable_Id], [Resolution_Depth], [Dependant_Deployable_Id], [DependsOn_Deployable_Id])
		SELECT
		  [Base_Deployable_Id], @depth, RD.[DependsOn_Deployable_Id], DD.[DependsOn_Deployable_Id]
		FROM @ResolvedDependencies RD
	         INNER JOIN [DeployableDependencies] DD
		             ON RD.[DependsOn_Deployable_Id] = DD.[Deployable_Id]
		WHERE RD.[Resolution_Depth] = @depth - 1

		SET @row_count = @@ROWCOUNT
	
		-- if a inserted deployable depends on itself (somewhere down the line) then shed tears
		IF EXISTS( SELECT * 
		             FROM [inserted] I
		                  INNER JOIN @ResolvedDependencies RD
		                          ON RD.[Resolution_Depth] > 1
		                         AND I.[Deployable_Id] = RD.[Base_Deployable_Id]
		                         AND I.[Deployable_Id] = RD.[Dependant_Deployable_Id] )

		BEGIN 
				RAISERROR('This insertion will cause a circular dependecy at depth %i, which is not supported.',16,2, @depth) 
				ROLLBACK
				RETURN 
		END 

		-- sanity check
		IF @depth > 1000 BEGIN
				RAISERROR('Depth exceeded 1000.',16,1) 
				ROLLBACK
				RETURN 
		END 
	END 


END
GO