EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_PromoteBuild',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Promotion_Id',
    /* Description_Text        */ 'Promotes a build to to a pipeline stage.'
GO

IF OBJECT_ID('[Builds_PromoteBuild]') IS NOT NULL DROP PROCEDURE [Builds_PromoteBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_PromoteBuild]
(
	@Build_Id INT,
	@Comments_Text VARCHAR(255),
	@ForcePromotion_Indicator YNINDICATOR,
	@PromoteTo_PipelineStage_Name VARCHAR(50),
	@SetFurthestStage_Indicator YNINDICATOR = NULL,
	@Promotion_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [BuildPromotions]
	(
		[Build_Id],
		[PipelineStage_Name],
		[PromotedBy_Name],
		[Comments_Text],
		[PromotionStatus_Name],
		[Forced_Indicator],
		[Promoted_Date]
	)
	VALUES
	(
		@Build_Id,
		@PromoteTo_PipelineStage_Name,
		dbo.Session_GetUserName(),
		NULLIF(@Comments_Text, ''),
		'AwaitingExecution',
		@ForcePromotion_Indicator,
		GETUTCDATE()
	)

	SET @Promotion_Id = SCOPE_IDENTITY()

	DELETE [BuildPromotionsScheduled]
	 WHERE [Build_Id] = @Build_Id
	   AND [PipelineStage_Name] = @PromoteTo_PipelineStage_Name

	IF @SetFurthestStage_Indicator = 'Y'
	BEGIN

		UPDATE [Builds]
		   SET [Furthest_PipelineStage_Name] = @PromoteTo_PipelineStage_Name
		 WHERE [Build_Id] = @Build_Id

	END

	DECLARE @Application_Id INT
	DECLARE @Release_Number RELEASENUMBER
	DECLARE @Build_Number BUILDNUMBER

	SELECT @Application_Id = B.[Application_Id],
	       @Release_Number = R.[Release_Number],
		   @Build_Number = B.[Build_Number]
	  FROM [Builds] B
	       LEFT JOIN [Releases] R
		          ON R.[Release_Id] = B.[Release_Id]

	IF @Release_Number IS NOT NULL
		EXEC [Events_RaiseEvent] 'BLDPMT', @Application_Id, @Release_Number, @Build_Number, @PromoteTo_PipelineStage_Name
	ELSE
		EXEC [Events_RaiseEvent] 'BLDPMT', @Application_Id, '', @Build_Number, @PromoteTo_PipelineStage_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH
		   
END
GO

GRANT EXECUTE ON [Builds_PromoteBuild] TO [BuildMasterUser_Role]
