EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_RejectBuild',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Rejects the specified build.'
GO

IF OBJECT_ID('[Builds_RejectBuild]') IS NOT NULL DROP PROCEDURE [Builds_RejectBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_RejectBuild]
(
	@Build_Id INT,
	@Rejection_Notes NVARCHAR(255) = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [Builds]
	   SET [BuildStatus_Name] = 'Rejected'
		  ,[Rejection_Notes] = @Rejection_Notes
		  ,[Rejected_Date] = GETUTCDATE()
		  ,[RejectedBy_User_Name] = dbo.Session_GetUserName()
	 WHERE [Build_Id] = @Build_Id
	   AND [BuildStatus_Name] <> 'Deployed'

	DELETE [BuildPromotionsScheduled]
	 WHERE [Build_Id] = @Build_Id

	UPDATE [Executions]
	   SET [CanceledBy_User_Name] = 'SYSTEM'
		  ,[CanceledOn_Date] = GETUTCDATE()
	 WHERE [ExecutionRunState_Code] IN ('P')
	   AND [Execution_Id] IN
	       ( SELECT [Execution_Id] FROM [PipelineStageTargetExecutions]
		      WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM [BuildPromotions] WHERE [Build_Id] = @Build_Id)
			 UNION 
			 SELECT [Execution_Id] FROM [PipelineStageDeploymentExecutions]
		      WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM [BuildPromotions] WHERE [Build_Id] = @Build_Id))

   	DECLARE @Application_Id INT
	DECLARE @Release_Number RELEASENUMBER
	DECLARE @Build_Number BUILDNUMBER

	SELECT @Build_Number = B.[Build_Number],
	       @Release_Number =  R.[Release_Number],
		   @Application_Id = B.[Application_Id]
	  FROM [Builds] B
	       LEFT JOIN [Releases] R
		          ON R.[Release_Id] = B.[Release_Id]
	 WHERE B.[Build_Id] = @Build_Id

	IF @Release_Number IS NOT NULL
		EXEC [Events_RaiseEvent] 'BLDRJC', @Application_Id, @Release_Number, @Build_Number
	ELSE
		EXEC [Events_RaiseEvent] 'BLDRJC', @Application_Id, '', @Build_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_RejectBuild] TO [BuildMasterUser_Role]