EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_DeployConfigurationFile',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ConfigurationFileDeployment_Id',
    /* Description_Text        */ 'Saves the result of a deployed configuration file (this will not physically deploy the configuration file).'
GO

IF OBJECT_ID('[ConfigurationFiles_DeployConfigurationFile]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_DeployConfigurationFile]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_DeployConfigurationFile]
(
	@Execution_Id INT,
	@ConfigurationFile_Id INT,
	@Instance_Name VARCHAR(100),
	@Version_Number INT,
	@Server_Id INT,
	@DeployedTo_Path VARCHAR(500),
	@DeployedBy_User_Name USERNAME,
	@ConfigurationFileDeployment_Id INT = NULL OUT
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Template_Indicator YNINDICATOR
	SET @Template_Indicator = (SELECT [Template_Indicator]
	                             FROM [ConfigurationFileInstances]
								WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
								  AND [Instance_Name] = @Instance_Name)

	IF @Template_Indicator IS NULL
		RAISERROR('Configuration file does not exist.', 16, 1)

	INSERT INTO [ConfigurationFileDeployments]
	(
		[ConfigurationFile_Id],
		[Execution_Id],
		[Instance_Name],
		[Version_Number],
		[Server_Id],
		[DeployedTo_Path],
		[DeployedBy_User_Name],
		[DeployedOn_Date]
	)
	VALUES
	(
		@ConfigurationFile_Id,
		@Execution_Id,
		@Instance_Name,
		@Version_Number,
		@Server_Id,
		@DeployedTo_Path,
		COALESCE(@DeployedBy_User_Name, dbo.Session_GetUserName()),
		GETUTCDATE()
	)

	SET @ConfigurationFileDeployment_Id = SCOPE_IDENTITY()

	DECLARE @Application_Id INT
	    SET @Application_Id = (SELECT [Application_Id] 
	                             FROM [ConfigurationFiles]
 	                            WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id)

	EXEC [Events_RaiseEvent] 'CFGDPL', @Application_Id, @ConfigurationFileDeployment_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_DeployConfigurationFile] TO [BuildMasterUser_Role]
