EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'DatabaseConnections_CreateOrUpdateConnection',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'DatabaseConnection_Id',
    /* Description_Text        */ 'Creates a new database connection or updates an existing one.'
GO


IF OBJECT_ID('[DatabaseConnections_CreateOrUpdateConnection]') IS NOT NULL DROP PROCEDURE [DatabaseConnections_CreateOrUpdateConnection]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [DatabaseConnections_CreateOrUpdateConnection]
(
	@DatabaseConnection_Name NVARCHAR(50),
	@DatabaseConnection_Description NVARCHAR(MAX),
	@DatabaseConnection_Configuration XML,
	@ExecuteOn_Server_Id INT,
	@Application_Id INT,
	@Environment_Id INT,
	@RestrictEnvironment_Indicator YNINDICATOR,
	@DatabaseConnection_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @DatabaseConnection_Id IS NULL
	BEGIN
		
		INSERT INTO [DatabaseConnections]
		(
			[DatabaseConnection_Name],
			[DatabaseConnection_Description],
			[DatabaseConnection_Configuration],
			[ExecuteOn_Server_Id],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date],
			[Application_Id],
			[Environment_Id],
			[RestrictEnvironment_Indicator] 
		)
		VALUES
		(
			NULLIF(@DatabaseConnection_Name, ''),
			NULLIF(@DatabaseConnection_Description, ''),
			@DatabaseConnection_Configuration,
			@ExecuteOn_Server_Id,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			@Application_Id,
			@Environment_Id,
			@RestrictEnvironment_Indicator
		)

		SET @DatabaseConnection_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [DatabaseConnections]
		   SET [DatabaseConnection_Name] = NULLIF(@DatabaseConnection_Name, ''),
		       [DatabaseConnection_Description] = NULLIF(@DatabaseConnection_Description, ''),
			   [DatabaseConnection_Configuration] = @DatabaseConnection_Configuration,
			   [ExecuteOn_Server_Id] = @ExecuteOn_Server_Id,
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedOn_Date] = GETUTCDATE(),
			   [Environment_Id] = @Environment_Id,
			   [RestrictEnvironment_Indicator]  = @RestrictEnvironment_Indicator
	        WHERE [DatabaseConnection_Id] = @DatabaseConnection_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DatabaseConnections_CreateOrUpdateConnection] TO [BuildMasterUser_Role]