EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Promotions_AddApproval',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Approval_Id',
    /* Description_Text        */ 'Adds an approval for a promotion.'
GO

IF OBJECT_ID('[Promotions_AddApproval]') IS NOT NULL DROP PROCEDURE [Promotions_AddApproval]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Promotions_AddApproval]
(
	@Build_Id INT,
	@PipelineStage_Name VARCHAR(50),
	@Requirement_Id INT,
	@RequirementType_Code CHAR(2),
	@User_Name USERNAME,
	@Requirement_Description NVARCHAR(1000),
	@Comments_Text NVARCHAR(1000) = NULL,
	@Approval_Id INT = NULL OUT
) AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [BuildPromotions_Extended]
			   WHERE [Build_Id] = @Build_Id
				 AND [PipelineStage_Name] = @PipelineStage_Name)
	BEGIN
		RAISERROR('Build has already been promoted. Cannot add approval.', 16, 1)
	END

	INSERT INTO [BuildApprovalsReceived]
	(
		[Build_Id],
		[PipelineStage_Name],
		[Original_Requirement_Id],
		[RequirementType_Code],
		[User_Name],
		[Comments_Text],
		[Received_Date],
		[Requirement_Description]
	)
	VALUES
	(
		@Build_Id,
		@PipelineStage_Name,
		@Requirement_Id,
		@RequirementType_Code,
		@User_Name,
		NULLIF(@Comments_Text, ''),
		GETUTCDATE(),
		@Requirement_Description
	)

	SET @Approval_Id = SCOPE_IDENTITY()

	DECLARE @Application_Id INT
	SELECT @Application_Id = [Application_Id]
	  FROM [Builds]
	 WHERE [Build_Id] = @Build_Id

	EXEC [Events_RaiseEvent] 'BLDAPR', @Application_Id, @Approval_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Promotions_AddApproval] TO [BuildMasterUser_Role]